"use strict";
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.opts = exports.displayName = void 0;
const side_code_export_1 = require("@seleniumhq/side-code-export");
const command_1 = __importDefault(require("./command"));
const location_1 = __importDefault(require("./location"));
const hook_1 = __importDefault(require("./hook"));
// Define language options
exports.displayName = 'Python pytest';
exports.opts = {
    emitter: command_1.default,
    displayName: exports.displayName,
    name: 'python-pytest',
    hooks: (0, side_code_export_1.generateHooks)(hook_1.default),
    fileExtension: '.py',
    commandPrefixPadding: '  ',
    terminatingKeyword: '',
    commentPrefix: '#',
    // Create generators for dynamic string creation of primary entities (e.g., filename, methods, test, and suite)
    generateTestDeclaration: function generateTestDeclaration(name) {
        return `def test_${side_code_export_1.codeExport.parsers.uncapitalize(side_code_export_1.codeExport.parsers.sanitizeName(name))}(self):`;
    },
    generateMethodDeclaration: function generateMethodDeclaration(name) {
        return `def ${side_code_export_1.codeExport.parsers.uncapitalize(side_code_export_1.codeExport.parsers.sanitizeName(name))}(self):`;
    },
    generateSuiteDeclaration: function generateSuiteDeclaration(name) {
        return `class Test${side_code_export_1.codeExport.parsers.capitalize(side_code_export_1.codeExport.parsers.sanitizeName(name))}():`;
    },
    generateFilename: function generateFilename(name) {
        return `test_${side_code_export_1.codeExport.parsers.uncapitalize(side_code_export_1.codeExport.parsers.sanitizeName(name))}${exports.opts.fileExtension}`;
    },
};
const language = {
    emit: {
        locator: location_1.default.emit,
        command: command_1.default.emit,
        suite: async function emitSuite({ baseUrl, suite, tests, project, enableOriginTracing, beforeEachOptions, enableDescriptionAsComment, }) {
            // @ts-expect-error globals yuck
            global.baseUrl = baseUrl;
            const result = await side_code_export_1.codeExport.emit.testsFromSuite(tests, suite, exports.opts, {
                enableOriginTracing,
                generateTestDeclaration: exports.opts.generateTestDeclaration,
                enableDescriptionAsComment,
                project,
            });
            const suiteDeclaration = exports.opts.generateSuiteDeclaration(suite.name);
            const _suite = await side_code_export_1.codeExport.emit.suite(result, tests, {
                ...exports.opts,
                suiteDeclaration,
                suite,
                suiteName: suite.name,
                project,
                beforeEachOptions,
            });
            return {
                filename: exports.opts.generateFilename(suite.name),
                body: side_code_export_1.codeExport.emit.orderedSuite(_suite),
            };
        },
        // Emit an individual test, wrapped in a suite (using the test name as the suite name)
        test: async function emitTest({ baseUrl, test, tests, project, enableOriginTracing, beforeEachOptions, enableDescriptionAsComment, }) {
            // @ts-expect-error globals yuck
            global.baseUrl = baseUrl;
            const testDeclaration = exports.opts.generateTestDeclaration(test.name);
            const result = await side_code_export_1.codeExport.emit.test(test, tests, {
                ...exports.opts,
                testDeclaration,
                enableOriginTracing,
                enableDescriptionAsComment,
                project,
            });
            const suiteName = test.name;
            const suiteDeclaration = exports.opts.generateSuiteDeclaration(suiteName);
            const _suite = await side_code_export_1.codeExport.emit.suite(result, tests, {
                ...exports.opts,
                suiteDeclaration,
                suiteName,
                project,
                beforeEachOptions,
            });
            return {
                filename: exports.opts.generateFilename(test.name),
                body: side_code_export_1.codeExport.emit.orderedSuite(_suite),
            };
        },
    },
    opts: exports.opts,
    register: {
        command: command_1.default.register,
        variable: exports.opts.hooks.declareVariables.register,
        dependency: exports.opts.hooks.declareDependencies.register,
        beforeAll: exports.opts.hooks.beforeAll.register,
        beforeEach: exports.opts.hooks.beforeEach.register,
        afterEach: exports.opts.hooks.afterEach.register,
        afterAll: exports.opts.hooks.afterAll.register,
        inEachBegin: exports.opts.hooks.inEachBegin.register,
        inEachEnd: exports.opts.hooks.inEachEnd.register,
    },
};
exports.default = language;
//# sourceMappingURL=index.js.map